==> wamblee-safe-0.4-sources.jar: org/wamblee/safe/wicket/WicketApplication.java <==
/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.safe.wicket;

import javax.servlet.http.HttpServletRequest;

import org.apache.wicket.Request;
import org.apache.wicket.RequestCycle;
import org.apache.wicket.Response;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.protocol.http.WebRequest;
import org.apache.wicket.request.target.basic.RedirectRequestTarget;
import org.apache.wicket.settings.IApplicationSettings;
import org.wamblee.wicket.inject.ComponentInstantiationInjector;
import org.wamblee.wicket.transactions.OpenTransactionInViewRequestCycle;

/**
 * Application object for your web application. If you want to run this
 * application without deploying, run the Start class.
 * 
 * @see org.wamblee.Start#main(String[])
 */
public class WicketApplication extends WebApplication {

    /**
     * Constructor
     */
    public WicketApplication() {
        // Empty.
    }

    @Override
    public RequestCycle newRequestCycle(Request aRequest, Response aResponse) {
        return new OpenTransactionInViewRequestCycle(this,
            (WebRequest) aRequest, aResponse);
    }

    @Override
    protected void init() {
        super.init();
        addComponentInstantiationListener(new ComponentInstantiationInjector());

        IApplicationSettings settings = getApplicationSettings();
        settings.setInternalErrorPage(ErrorPage.class);

        // Use the lines below to get the internal error page also when in
        // development mode.
        // IExceptionSettings exs = getExceptionSettings();
        // exs.setUnexpectedExceptionDisplay(IExceptionSettings.SHOW_INTERNAL_ERROR_PAGE);
    }

    /**
     * @see org.apache.wicket.Application#getHomePage()
     */
    public Class<HomePage> getHomePage() {
        return HomePage.class;
    }

}

==> wamblee-safe-0.7-sources.jar: org/wamblee/safe/wicket/WicketApplication.java <==
/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.safe.wicket;

import org.apache.wicket.Request;
import org.apache.wicket.RequestCycle;
import org.apache.wicket.Response;
import org.apache.wicket.Session;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.protocol.http.WebRequest;
import org.apache.wicket.settings.IApplicationSettings;
import org.wamblee.wicket.inject.ComponentInstantiationInjector;
import org.wamblee.wicket.transactions.OpenTransactionInViewRequestCycle;

/**
 * Application object for your web application. If you want to run this
 * application without deploying, run the Start class.
 */
public class WicketApplication extends WebApplication {

    /**
     * Constructor
     */
    public WicketApplication() {
        // Empty.
    }

    @Override
    public RequestCycle newRequestCycle(Request aRequest, Response aResponse) {
        return new OpenTransactionInViewRequestCycle(this, (WebRequest) aRequest, aResponse);
    }

    @Override
    protected void init() {
        super.init();
        addComponentInstantiationListener(new ComponentInstantiationInjector());

        IApplicationSettings settings = getApplicationSettings();
        settings.setInternalErrorPage(ErrorPage.class);

        // Use the lines below to get the internal error page also when in
        // development mode.
        // IExceptionSettings exs = getExceptionSettings();
        // exs.setUnexpectedExceptionDisplay(IExceptionSettings.SHOW_INTERNAL_ERROR_PAGE);
    }

    /**
     * @see org.apache.wicket.Application#getHomePage()
     */
    public Class<HomePage> getHomePage() {
        return HomePage.class;
    }

    @Override
    public Session newSession(Request aRequest, Response aResponse) {
        return new SafeSession(aRequest);
    }
}
